@@ -2,7 +2,7 @@
 import factory
 
 from ..factories import HvadFactoryMixin, UserFactory
-from models import DummyProfile, DummyProfileTranslation, HvadDummy
+from models import DummyProfile, HvadDummy
 
 
 class HvadDummyFactory(HvadFactoryMixin, factory.DjangoModelFactory):
@@ -18,11 +18,3 @@ class DummyProfileFactory(factory.DjangoModelFactory):
 
     user = factory.SubFactory(UserFactory)
     dummy_field = factory.Sequence(lambda n: 'dummyfield{}'.format(n))
-
-
-class DummyProfileTranslationFactory(factory.DjangoModelFactory):
-    """Factory for the ``DummyProfileTranslation`` model."""
-    FACTORY_FOR = DummyProfileTranslation
-
-    dummy_translation = factory.Sequence(lambda n: 'trans {}'.format(n))
-    dummyprofile = factory.SubFactory(DummyProfileFactory)
